ArrayHandle

Struct ArrayHandle 

pub struct ArrayHandle<T> { /* private fields */ }
A handle granting array-wide access to a bimodal_array.

An ArrayHandle represents the capability to acquire an exclusive lock for the entire collection. The actual lock is held by the returned ArrayGuard, which provides mutable access to the full slice &mut [T].

Locking Semantics

Lock acquisition is non-blocking.

Implementations

Source

impl<T> ArrayHandle<T>

pub fn lock<'a>(&'a mut self) -> Result<ArrayGuard<'a, T>, BimodalArrayError>

Attempts to acquire exclusive mutable access to the entire array.

Returns an ArrayGuard on success. If any element guards are currently active, this method returns BimodalArrayError::CouldNotAcquireArrayLock.

Lock acquisition is non-blocking.