pub struct ArrayHandle<T> { /* private fields */ }Expand description
A handle granting array-wide access to a bimodal_array.
An ArrayHandle represents the capability to acquire an exclusive lock for
the entire collection. The actual lock is held by the returned
ArrayGuard, which provides mutable access to the full slice &mut [T].
Locking Semantics
- Calling
lockattempts to acquire array-wide exclusive access. - If successful, it returns an
ArrayGuardproviding&mut [T]. - If one or more
ElementGuard<T>values are currently active, lock acquisition fails withBimodalArrayError::CouldNotAcquireArrayLock.
Lock acquisition is non-blocking.
Implementations
Sourceimpl<T> ArrayHandle<T>
impl<T> ArrayHandle<T>
Sourcepub fn lock<'a>(&'a mut self) -> Result<ArrayGuard<'a, T>, BimodalArrayError>
pub fn lock<'a>(&'a mut self) -> Result<ArrayGuard<'a, T>, BimodalArrayError>
Attempts to acquire exclusive mutable access to the entire array.
Returns an ArrayGuard on success. If any element guards are
currently active, this method returns
BimodalArrayError::CouldNotAcquireArrayLock.
Lock acquisition is non-blocking.