pub struct ElementGuard<'a, T> { /* private fields */ }Expand description
A guard providing mutable access to a single element.
An ElementGuard is returned by ElementHandle::lock. While an
ElementGuard is alive:
- No
ArrayGuard<T>can be acquired. - No other
ElementGuardfor the same element can exist.
Guards for different elements may coexist concurrently.
The guard dereferences to &mut T, allowing direct mutation of the
underlying element.
RAII Semantics
The element-level lock is released automatically when this guard is dropped. This ensures that access is tied to the lifetime of the guard.
Examples
let data = vec![0];
let (_, mut elements) = bimodal_array(data);
let mut guard = elements[0].lock().unwrap();
*guard = 42;
// Lock is released here when `guard` is dropped.Trait Implementations
Sourceimpl<'a, T> Deref for ElementGuard<'a, T>
impl<'a, T> Deref for ElementGuard<'a, T>
Sourceimpl<'a, T> DerefMut for ElementGuard<'a, T>
impl<'a, T> DerefMut for ElementGuard<'a, T>